@@ -7,6 +7,7 @@
 #include "navitiabackend.h"
 #include "logging.h"
 #include "navitiaparser.h"
+#include "navitiaphysicalmode.h"
 #include "cache.h"
 
 #include <KPublicTransport/Journey>
@@ -91,6 +92,7 @@ bool NavitiaBackend::queryJourney(const JourneyRequest &req, JourneyReply *reply
             query.addQueryItem(QStringLiteral("datetime_represents"), req.dateTimeMode() == JourneyRequest::Arrival ? QStringLiteral("arrival") : QStringLiteral("departure"));
         }
         query.addQueryItem(QStringLiteral("count"), QString::number(std::max(1, req.maximumResults())));
+        NavitiaPhysicalMode::lineModesToQuery(req.lineModes(), query);
         addModeArgument(QStringLiteral("first_section_mode[]"), req.accessModes(), query);
         addModeArgument(QStringLiteral("last_section_mode[]"), req.egressModes(), query);
 
@@ -160,6 +162,7 @@ bool NavitiaBackend::queryStopover(const StopoverRequest &req, StopoverReply *re
     query.addQueryItem(QStringLiteral("disable_geojson"), QStringLiteral("true"));
     query.addQueryItem(QStringLiteral("depth"), QStringLiteral("0"));
     query.addQueryItem(QStringLiteral("count"), QString::number(std::max(1, req.maximumResults())));
+    NavitiaPhysicalMode::lineModesToQuery(req.lineModes(), query);
     url.setQuery(query);
 
     QNetworkRequest netReq(url);
@@ -225,13 +228,15 @@ bool NavitiaBackend::queryLocation(const LocationRequest &req, LocationReply *re
     }
 
     if (req.hasCoordinate()) {
-        url.setPath(
-            QStringLiteral("/v1/coord/") + QString::number(req.longitude()) + QLatin1Char(';') + QString::number(req.latitude()) +
-            QStringLiteral("/places_nearby")
-        );
+        url.setPath(QStringLiteral("/v1") +
+            (m_coverage.isEmpty() ? QString() : (QStringLiteral("/coverage/") + m_coverage)) +
+            QStringLiteral("/coord/") + QString::number(req.longitude()) + QLatin1Char(';') + QString::number(req.latitude()) +
+            QStringLiteral("/places_nearby"));
         query.addQueryItem(QStringLiteral("distance"), QString::number(std::max(1, req.maximumDistance())));
     } else if (!req.name().isEmpty()) {
-        url.setPath(QStringLiteral("/v1/places"));
+        url.setPath(QStringLiteral("/v1") +
+            (m_coverage.isEmpty() ? QString() : (QStringLiteral("/coverage/") + m_coverage)) +
+            QStringLiteral("/places"));
         query.addQueryItem(QStringLiteral("q"), req.name());
     } else {
         return false;
